@@ -29,10 +29,14 @@ use crate::common::{
     ende::{SimpleVisitor, ValueEnDe},
     BranchID, Pre, PreBytes, RawValue, VersionID, VSDB,
 };
+use once_cell::sync::Lazy;
+use parking_lot::Mutex;
 use ruc::*;
 use serde::{Deserialize, Serialize};
 use std::{ops::RangeBounds, result::Result as StdResult};
 
+static LEN_LK: Lazy<Mutex<()>> = Lazy::new(|| Mutex::new(()));
+
 /////////////////////////////////////////////////////////////////////////////
 /////////////////////////////////////////////////////////////////////////////
 
@@ -80,18 +84,18 @@ pub trait Engine: Sized {
 
     fn set_instance_len(&self, instance_prefix: PreBytes, new_len: u64);
 
+    #[allow(unused_variables)]
     fn increase_instance_len(&self, instance_prefix: PreBytes) {
-        self.set_instance_len(
-            instance_prefix,
-            self.get_instance_len(instance_prefix) + 1,
-        )
+        let x = LEN_LK.lock();
+        let l = self.get_instance_len(instance_prefix);
+        self.set_instance_len(instance_prefix, l + 1)
     }
 
+    #[allow(unused_variables)]
     fn decrease_instance_len(&self, instance_prefix: PreBytes) {
-        self.set_instance_len(
-            instance_prefix,
-            self.get_instance_len(instance_prefix) - 1,
-        )
+        let x = LEN_LK.lock();
+        let l = self.get_instance_len(instance_prefix);
+        self.set_instance_len(instance_prefix, l - 1)
     }
 }
 
@@ -179,7 +183,7 @@ impl Mapx {
     #[inline(always)]
     pub(crate) fn clear(&self) {
         VSDB.db.iter(self.area_idx, self.prefix).for_each(|(k, _)| {
-            VSDB.db.remove(self.area_idx, self.prefix, &k);
+            VSDB.db.remove(self.area_idx, self.prefix, &k).unwrap();
             VSDB.db.decrease_instance_len(self.prefix);
         });
     }
