@@ -58,10 +58,10 @@ impl Engine for SledEngine {
 
     // 'step 1' and 'step 2' is not atomic in multi-threads scene,
     // so we use a `Mutex` lock for thread safe.
+    #[allow(unused_variables)]
     fn alloc_prefix(&self) -> Pre {
-        static LK: Lazy<Mutex<bool>> = Lazy::new(|| Mutex::new(false));
-
-        let mut z = LK.lock();
+        static LK: Lazy<Mutex<()>> = Lazy::new(|| Mutex::new(()));
+        let x = LK.lock();
 
         // step 1
         let ret = crate::parse_prefix!(
@@ -77,18 +77,15 @@ impl Engine for SledEngine {
             .insert(self.prefix_allocator.key, (1 + ret).to_be_bytes())
             .unwrap();
 
-        // meaningless but keep the lock
-        *z = false;
-
         ret
     }
 
     // 'step 1' and 'step 2' is not atomic in multi-threads scene,
     // so we use a `Mutex` lock for thread safe.
+    #[allow(unused_variables)]
     fn alloc_branch_id(&self) -> BranchID {
         static LK: Lazy<Mutex<bool>> = Lazy::new(|| Mutex::new(false));
-
-        let mut z = LK.lock();
+        let x = LK.lock();
 
         // step 1
         let ret = crate::parse_int!(
@@ -101,18 +98,15 @@ impl Engine for SledEngine {
             .insert(META_KEY_BRANCH_ID, (1 + ret).to_be_bytes())
             .unwrap();
 
-        // meaningless but keep the lock
-        *z = false;
-
         ret
     }
 
     // 'step 1' and 'step 2' is not atomic in multi-threads scene,
     // so we use a `Mutex` lock for thread safe.
+    #[allow(unused_variables)]
     fn alloc_version_id(&self) -> VersionID {
         static LK: Lazy<Mutex<bool>> = Lazy::new(|| Mutex::new(false));
-
-        let mut z = LK.lock();
+        let x = LK.lock();
 
         // step 1
         let ret = crate::parse_int!(
@@ -129,9 +123,6 @@ impl Engine for SledEngine {
             .insert(META_KEY_VERSION_ID, (1 + ret).to_be_bytes())
             .unwrap();
 
-        // meaningless but keep the lock
-        *z = false;
-
         ret
     }
 
@@ -303,8 +294,7 @@ fn sled_open() -> Result<Db> {
     let mut cfg = Config::new()
         .path(&dir)
         .mode(Mode::HighThroughput)
-        .cache_capacity(10 * GB)
-        .flush_every_ms(Some(10000));
+        .cache_capacity(10 * GB);
 
     #[cfg(feature = "compress")]
     {
