@@ -817,7 +817,7 @@ impl MapxRawMkVs {
         self.branch_truncate(branch_id).c(d!())?;
 
         self.branch_id_to_branch_name
-            .get(&branch_id)
+            .remove(&branch_id)
             .c(d!())
             .and_then(|brname| self.branch_name_to_branch_id.remove(&brname).c(d!()))?;
 
@@ -827,6 +827,19 @@ impl MapxRawMkVs {
             .map(|_| ())
     }
 
+    #[inline(always)]
+    pub(super) fn branch_keep_only(&self, branch_ids: &[BranchID]) -> Result<()> {
+        for brid in self
+            .branch_id_to_branch_name
+            .iter()
+            .map(|(brid, _)| brid)
+            .filter(|brid| !branch_ids.contains(brid))
+        {
+            self.branch_remove(brid).c(d!())?;
+        }
+        self.version_clean_up_globally().c(d!())
+    }
+
     #[inline(always)]
     pub(super) fn branch_truncate(&self, branch_id: BranchID) -> Result<()> {
         self.branch_truncate_to(branch_id, VersionID::MIN).c(d!())
@@ -844,7 +857,7 @@ impl MapxRawMkVs {
             }
             Ok(())
         } else {
-            Err(eg!("branch not found"))
+            Err(eg!("branch not found: {}", branch_id))
         }
     }
 
